System.register(['./generated-shared.js'], (function () {
	'use strict';
	return {
		setters: [null],
		execute: (function () {

			console.log('main1');

		})
	};
}));
